#!/usr/bin/perl
#
# wintoatx.pl ##################################################################
#
# wintoatx {-n|-v} < input > output
#
# Convertor from Windows CP 1256 to ArabTeX ASCII transliteration
#
# The idea taken from mac2atx.pl by Abdelsalam Heddaya, Boston University
#
# 2000/06/14 by Otakar Smrz, Charles University, Prague ########################

%ArabTeX = (
                "\000", "\000", # 00
                "\001", "\001", # 01
                "\002", "\002", # 02
                "\003", "\003", # 03
                "\004", "\004", # 04
                "\005", "\005", # 05
                "\006", "\006", # 06
                "\007", "\007", # 07
                "\010", "\010", # 08
                "\011", "\011", # 09
                "\012", "\012", # 0A
                "\013", "\013", # 0B
                "\014", "\014", # 0C
                "\015", "\015", # 0D
                "\016", "\016", # 0E
                "\017", "\017", # 0F
                "\020", "\020", # 10
                "\021", "\021", # 11
                "\022", "\022", # 12
                "\023", "\023", # 13
                "\024", "\024", # 14
                "\025", "\025", # 15
                "\026", "\026", # 16
                "\027", "\027", # 17
                "\030", "\030", # 18
                "\031", "\031", # 19
                "\032", "\032", # 1A
                "\033", "\033", # 1B
                "\034", "\034", # 1C
                "\035", "\035", # 1D
                "\036", "\036", # 1E
                "\037", "\037", # 1F
                "\040", " ", # 20
                "\041", "!", # 21
                "\042", "\"", # 22
                "\043", "\#", # 23
                "\044", "\$", # 24
                "\045", "\%", # 25
                "\046", "\&", # 26
                "\047", "'", # 27
                "\050", "(", # 28
                "\051", ")", # 29
                "\052", "*", # 2A
                "\053", "+", # 2B
                "\054", ",", # 2C
                "\055", "-", # 2D
                "\056", ".", # 2E
                "\057", "/", # 2F
                "\060", "0", # 30
                "\061", "1", # 31
                "\062", "2", # 32
                "\063", "3", # 33
                "\064", "4", # 34
                "\065", "5", # 35
                "\066", "6", # 36
                "\067", "7", # 37
                "\070", "8", # 38
                "\071", "9", # 39
                "\072", ":", # 3A
                "\073", ";", # 3B
                "\074", "<", # 3C
                "\075", "=", # 3D
                "\076", ">", # 3E
                "\077", "?", # 3F
                "\100", "@", # 40
                "\101", "A", # 41
                "\102", "B", # 42
                "\103", "C", # 43
                "\104", "D", # 44
                "\105", "E", # 45
                "\106", "F", # 46
                "\107", "G", # 47
                "\110", "H", # 48
                "\111", "I", # 49
                "\112", "J", # 4A
                "\113", "K", # 4B
                "\114", "L", # 4C
                "\115", "M", # 4D
                "\116", "N", # 4E
                "\117", "O", # 4F
                "\120", "P", # 50
                "\121", "Q", # 51
                "\122", "R", # 52
                "\123", "S", # 53
                "\124", "T", # 54
                "\125", "U", # 55
                "\126", "V", # 56
                "\127", "W", # 57
                "\130", "X", # 58
                "\131", "Y", # 59
                "\132", "Z", # 5A
                "\133", "[", # 5B
                "\134", "\\", # 5C
                "\135", "]", # 5D
                "\136", "^", # 5E
                "\137", "_", # 5F
                "\140", "`", # 60
                "\141", "a", # 61
                "\142", "b", # 62
                "\143", "c", # 63
                "\144", "d", # 64
                "\145", "e", # 65
                "\146", "f", # 66
                "\147", "g", # 67
                "\150", "h", # 68
                "\151", "i", # 69
                "\152", "j", # 6A
                "\153", "k", # 6B
                "\154", "l", # 6C
                "\155", "m", # 6D
                "\156", "n", # 6E
                "\157", "o", # 6F
                "\160", "p", # 70
                "\161", "q", # 71
                "\162", "r", # 72
                "\163", "s", # 73
                "\164", "t", # 74
                "\165", "u", # 75
                "\166", "v", # 76
                "\167", "w", # 77
                "\170", "x", # 78
                "\171", "y", # 79
                "\172", "z", # 7A
                "\173", "{", # 7B
                "\174", "|", # 7C
                "\175", "}", # 7D
                "\176", "~", # 7E
                "\177", "\177", # 7F
                "\200", "\200", # 80
                "\201", "p", # 81
                "\202", "\202", # 82
                "\203", "\203", # 83
                "\204", "\204", # 84
                "\205", "\205", # 85
                "\206", "\206", # 86
                "\207", "\207", # 87
                "\210", "\210", # 88
                "\211", "\211", # 89
                "\212", "\212", # 8A
                "\213", "\213", # 8B
                "\214", "\214", # 8C
                "\215", "^c", # 8D
                "\216", "^z", # 8E
                "\217", "\217", # 8F
                "\220", "g", # 90
                "\221", "\221", # 91
                "\222", "\222", # 92
                "\223", "\223", # 93
                "\224", "\224", # 94
                "\225", "\225", # 95
                "\226", "\226", # 96
                "\227", "\227", # 97
                "\230", "\230", # 98
                "\231", "\231", # 99
                "\232", "\232", # 9A
                "\233", "\233", # 9B
                "\234", "\234", # 9C
                "\235", "\235", # 9D
                "\236", "\236", # 9E
                "\237", "\237", # 9F
                "\240", "\240", # A0
                "\241", ",", # A1
                "\242", "\242", # A2
                "\243", "\243", # A3
                "\244", "\244", # A4
                "\245", "\245", # A5
                "\246", "\246", # A6
                "\247", "\247", # A7
                "\250", "\250", # A8
                "\251", "\251", # A9
                "\252", "\252", # AA
                "\253", "\\lq ", # AB
                "\254", "\254", # AC
                "\255", "\255", # AD
                "\256", "\256", # AE
                "\257", "\257", # AF
                "\260", "\260", # B0
                "\261", "\261", # B1
                "\262", "\262", # B2
                "\263", "\263", # B3
                "\264", "\264", # B4
                "\265", "\265", # B5
                "\266", "\266", # B6
                "\267", "\267", # B7
                "\270", "\270", # B8
                "\271", "\271", # B9
                "\272", ";", # BA
                "\273", "\\rq", # BB
                "\274", "\274", # BC
                "\275", "\275", # BD
                "\276", "\276", # BE
                "\277", "?", # BF
                "\300", "\300", # C0
                "\301", "'", # C1
                "\302", "\\madda{}", # C2
                "\303", "\\ham{a}", # C3
                "\304", "\\ham{w}", # C4
                "\305", "\\ham{i}", # C5
                "\306", "\\ham{y}", # C6
                "\307", "\\alif{}", # C7
                "\310", "b", # C8
                "\311", "T", # C9
                "\312", "t", # CA
                "\313", "_t", # CB
                "\314", "^g", # CC
                "\315", ".h", # CD
                "\316", "_h", # CE
                "\317", "d", # CF
                "\320", "_d", # D0
                "\321", "r", # D1
                "\322", "z", # D2
                "\323", "s", # D3
                "\324", "^s", # D4
                "\325", ".s", # D5
                "\326", ".d", # D6
                "\327", "\327", # D7
                "\330", ".t", # D8
                "\331", ".z", # D9
                "\332", "`", # DA
                "\333", ".g", # DB
                "\334", "-", # DC
                "\335", "f", # DD
                "\336", "q", # DE
                "\337", "k", # DF
                "\340", "\340", # E0
                "\341", "l", # E1
                "\342", "\342", # E2
                "\343", "m", # E3
                "\344", "n", # E4
                "\345", "h", # E5
                "\346", "w", # E6
                "\347", "\347", # E7
                "\350", "\350", # E8
                "\351", "\351", # E9
                "\352", "\352", # EA
                "\353", "\353", # EB
                "\354", "\\maq{}", # EC
                "\355", "y", # ED
                "\356", "\356", # EE
                "\357", "\357", # EF
                "\360", "\\vow{aN}", # F0
                "\361", "\\vow{uN}", # F1
                "\362", "\\vow{iN}", # F2
                "\363", "\\vow{a}", # F3
                "\364", "\364", # F4
                "\365", "\\vow{u}", # F5
                "\366", "\\vow{i}", # F6
                "\367", "\367", # F7
                "\370", "\\shadda{}", # F8
                "\371", "\371", # F9
                "\372", "\\sukun{}", # FA
                "\373", "\373", # FB
                "\374", "\374", # FC
                "\375", "\375", # FD
                "\376", "\376", # FE
                "\377", "\377", # FF
        );

open(AUX,">wintoatx.aux");
until (eof(STDIN))
{
 $char=getc(STDIN);
 print AUX $ArabTeX{$char};
}
close(AUX);

open(AUX,"<wintoatx.aux");
$text=join("",<AUX>);

$text=~s/([_.\^]?\w)\\shadda{}/$1$1/g;
$text=~s/(\\ham{.})\\shadda{}/$1$1/g;

$text=~s/([=\s-%])\\alif{}\\vow{a}l/$1"al-/g;
$text=~s/([=\s-%])\\alif{}l/$1al-/g;
$text=~s/(b\\vow{i})\\alif{}l/$1-al-/g;
$text=~s/([=\s-%])\\alif{}\\vow{([ui])}/$1"$2/g;
$text=~s/([=\s-%])\\alif{}/$1i/g;
$text=~s/(\\vow{aN})\\alif{}/$1/g;
$text=~s/\\alif{}(\\vow{aN})/$1/g;
$text=~s/\\vow{a}\\alif{}/\\vow{A}/g;
$text=~s/\\alif{}/\\aux{A}/g;

$text=~s/\\madda{}/'A/g;

$text=~s/\\vow{a}\\maq{}/\\vow{Y}/g;
$text=~s/\\maq{}(\\vow{aN})/\\vow{aNY}/g;
$text=~s/\\vow{aN}\\maq{}/\\vow{aNY}/g;
$text=~s/\\maq{}/\\aux{Y}/g;

$text=~s/i(}?)y([^aiuAIUY])/I$1$2/g;
$text=~s/u(}?)w([^aiuAIUY])/U$1$2/g;

$text=~s/([iIuU]})(\\ham{a})/$1-$2/g;
$text=~s/([-\s])\\ham{a}([^\\])/$1'\\aux{a}$2/g;
$text=~s/([^}\s])\\ham{a}/$1\\aux{a}'/g;

$text=~s/([^-\s])(\\ham{i})/$1-$2/g;
$text=~s/\\ham{i}([^\\])/'\\aux{i}$1/g;

$text=~s/([^}])(\\ham{w})/$1\\aux{u}$2/g;
$text=~s/(\\ham{w})([^\\])/$1\\aux{u}$2/g;

$text=~s/([^}])(\\ham{y})/$1\\aux{i}$2/g;
$text=~s/(\\ham{y})([^\\])/$1\\aux{i}$2/g;

$text=~s/\\ham{[aiwy]}/'/g;

if ($ARGV[0] eq '-n')
{
 $text=~s/\\vow{(.+?)}/"$1/g;
 $text=~s/\\aux{(.+?)}/$1/g;
 $text=~s/\\sukun{}/"/g;
}
elsif ($ARGV[0] eq '-v')
{
 $text=~s/\\vow{(.+?)}/$1/g;
 $text=~s/\\aux{(.+?)}/"$1/g;
 $text=~s/\\sukun{}/"/g;
}
else
{
 $text=~s/\\vow{(.+?)}/$1/g;
 $text=~s/\\aux{(.+?)}/$1/g;
 $text=~s/\\sukun{}//g;
}

close(AUX);

print STDOUT $text;
